:py:mod:`icclim.threshold`
==========================

.. py:module:: icclim.threshold

.. autoapi-nested-parse::

   Threshold package.

   This package contains the threshold definitions used in conjunction with generic indices
   to create personalized indices.



Submodules
----------
.. toctree::
   :titlesonly:
   :maxdepth: 1

   factory/index.rst
